@@ -84,7 +84,6 @@ BostonHousing <- BostonHousing[
   sample.int(nrow(BostonHousing), 200, replace = FALSE), ]
 
 library("survival")
-data(lung, package = "survival", envir = environment())
-Lung <- lung
+Lung <- survival::lung
 Lung$sex <- factor(Lung$sex)
 Lung <- Lung[complete.cases(Lung), ]
