@@ -59,6 +59,18 @@ test_that("Get previous results with airquality and pre function", {
   # save_to_test(airq.ens, "airquality_w_pre_with_glmtree")
   expect_equal(airq.ens, read_to_test("airquality_w_pre_with_glmtree"), tolerance = 1.49e-08)
   
+  ####
+  # (hidden) argument offset is passed to function glmtree and cv.glmnet
+  set.seed(42)
+  airq.ens.offs <- pre(Ozone ~ ., data = airquality, use.grad = FALSE, ntrees = 10, 
+                       offset = airquality$Wind)
+  expect(nrow(airq.ens$rules) != nrow(airq.ens.offs$rules), 
+         failure = "Use of offset does not affect the number of generated rules (which it previously did.")
+  expect(is.null(airq.ens.offs$glmnet.fit$call$offset) != is.null(airq.ens$glmnet.fit$call$offset),
+         failure = "Argument offset might not be correcltly passed to cv.glmnet")
+  # save_to_test(airq.ens.offs, "airquality_w_pre_with_glmtree_w_offset")
+  expect_equal(airq.ens.offs, read_to_test("airquality_w_pre_with_glmtree_w_offset"), tolerance = 1.49e-08)
+  
   #####
   # Works with adaptive lasso
   set.seed(42)
@@ -76,7 +88,7 @@ test_that("Get previous results with airquality and pre function", {
   # save_to_test(airq.ens, "airquality_w_pre_with_relaxed_adaptive_lasso")
   expect_equal(airq.ens, read_to_test("airquality_w_pre_with_relaxed_adaptive_lasso"), tolerance = 1.49e-08)
   
-  ####
+  #### 
   # Relaxed (adaptive) lasso works with function prune_pre
   a <- capture.output(prune_pre(airq.ens, nonzero = 2))
   # save_to_test(a, "airquality_w_relaxed_pre_with_prune_pre")
